import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates a new comment and publishes it.
 *
 * The `appId`, `contextId`, and `resourceId` are all required and associate the created comment with the specific
 * resource it responds to. See **Integrations** in the Comments introduction for a list of integrated scopes for these fields.
 *
 * If the created comment is a direct response to another comment, the `commentId` of the parent comment should be passed
 * as `parentComment.id` in this comment's request. See **Terminology** in the Comments introduction for additional information on parent comments and replies.
 */
export declare function createComment(payload: object): RequestOptionsFactory<any>;
/** Retrieves a comment. */
export declare function getComment(payload: object): RequestOptionsFactory<any>;
/**
 * Updates a comment.
 *
 * Each time the comment is updated, `revision` increments by 1. The current `revision` must be
 * passed when updating the comment. This ensures you're working with the latest comment and
 * prevents unintended overwrites.
 */
export declare function updateComment(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a comment.
 *
 * This method deletes the `content` of the comment and sets its `status` to `DELETED`.
 */
export declare function deleteComment(payload: object): RequestOptionsFactory<any>;
/**
 * Moderates the draft content of a comment.
 *
 * - `APPROVE`: Moves `draftContent` to `content` and updates the comment `status` to `PUBLISHED`.
 * - `REJECT`: Clears `draftContent` if comment `status` is `PUBLISHED` or, if comment `status` is `PENDING` it will keep `draftContent` the same and change `status` to `HIDDEN`.
 */
export declare function moderateDraftContent(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a query to retrieve a list of comments.
 *
 * The `queryComments()` function builds a query to retrieve a list of comments and returns a [`CommentsQueryBuilder`](#commentsquerybuilder) object.
 *
 * The returned object contains the query definition, which is typically used to run the query using the [`find()`](#commentsquerybuilder/find) function.
 *
 * You can refine the query by chaining `CommentsQueryBuilder` functions onto the query. `CommentsQueryBuilder` functions enable you to sort, filter, and control the results that `queryComments()` returns.
 *
 * `queryComments()` runs with the following `CommentsQueryBuilder` default that you can override:
 * + `ascending("_id")`
 *
 * The functions that are chained to `queryComments()` are applied in the order they are called. For example, if you apply `ascending("voteSummary.netVoteCount")` and then `ascending("replyCount")`, the results are sorted first by the `"voteSummary.netVoteCount"`, and then, if there are multiple results with the same `"voteSummary.netVoteCount"`, the items are sorted by `"replyCount"`.
 *
 * The following `CommentsQueryBuilder` functions are supported for the `queryComments()` function. For a full description of the comment object, see the object returned for the [`items`](#commentsqueryresult/items) property in [`CommentsQueryResult`](#commentsqueryresult).
 */
export declare function queryComments(payload: object): RequestOptionsFactory<any>;
/**
 * Sets `marked` to `TRUE` to mark a comment.
 *
 * Call Query Comments to filter for marked comments to then apply customization to.
 * See Sample Flows for an example.
 */
export declare function markComment(payload: object): RequestOptionsFactory<any>;
/** Sets `marked` to `FALSE` to unmark a comment. */
export declare function unmarkComment(payload: object): RequestOptionsFactory<any>;
/** Hides a comment in a widget. The comment status becomes `HIDDEN`. */
export declare function hideComment(payload: object): RequestOptionsFactory<any>;
/**
 * Publishes a comment with the `HIDDEN` status. The comment status becomes `PUBLISHED`.
 *
 * To publish a new comment, call Create Comment.
 */
export declare function publishComment(payload: object): RequestOptionsFactory<any>;
/** Counts comments, given the specified filtering. Comments with the `HIDDEN` status are not included in the response. */
export declare function countComments(payload: object): RequestOptionsFactory<any>;
/** Lists published comments and replies from a specified resource, such as a blog post. */
export declare function listCommentsByResource(payload: object): RequestOptionsFactory<any>;
/**
 * Returns a thread of a comment or a reply.
 *
 * If you request a comment thread, the method returns a single comment with cursors. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
 *
 * If you request a reply thread, the method returns a reply with its parent comment. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
 */
export declare function getCommentThread(payload: object): RequestOptionsFactory<any>;
/** Publishes multiple comments with the `HIDDEN` status. The comment status becomes `PUBLISHED`. */
export declare function bulkPublishComment(payload: object): RequestOptionsFactory<any>;
/** Hides multiple comments. The comment status becomes `HIDDEN`. */
export declare function bulkHideComment(payload: object): RequestOptionsFactory<any>;
/** Deletes multiple comments. */
export declare function bulkDeleteComment(payload: object): RequestOptionsFactory<any>;
/** Moderates the draft content of multiple comments. */
export declare function bulkModerateDraftContent(payload: object): RequestOptionsFactory<any>;
/** Moves multiple comments to another resource. */
export declare function bulkMoveCommentByFilter(payload: object): RequestOptionsFactory<any>;
