import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { BulkDeleteCommentOptions, BulkDeleteCommentResponse, BulkHideCommentOptions, BulkHideCommentResponse, BulkModerateDraftContentOptions, BulkModerateDraftContentResponse, BulkMoveCommentByFilterOptions, BulkMoveCommentByFilterResponse, BulkPublishCommentOptions, BulkPublishCommentResponse, Comment, CommentContentChangedEnvelope, CommentCreatedEnvelope, CommentHiddenEnvelope, CommentMarkedEnvelope, CommentMovedEnvelope, CommentPublishedEnvelope, CommentResourceCommentCountChangedEnvelope, CommentUnmarkedEnvelope, CommentUpdatedEnvelope, CommentsQueryBuilder, CountCommentsOptions, CountCommentsResponse, GetCommentThreadOptions, GetCommentThreadResponse, HideCommentResponse, ListCommentsByResourceOptions, ListCommentsByResourceResponse, MarkCommentResponse, ModerateDraftContentOptions, ModerateDraftContentResponse, PublishCommentResponse, UnmarkCommentResponse, UpdateComment } from './comments-v2-comment-comments.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createComment(httpClient: HttpClient): CreateCommentSignature;
interface CreateCommentSignature {
    /**
     * Creates a new comment and publishes it.
     *
     * The `appId`, `contextId`, and `resourceId` are all required and associate the created comment with the specific
     * resource it responds to. See **Integrations** in the Comments introduction for a list of integrated scopes for these fields.
     *
     * If the created comment is a direct response to another comment, the `commentId` of the parent comment should be passed
     * as `parentComment.id` in this comment's request. See **Terminology** in the Comments introduction for additional information on parent comments and replies.
     * @param - Comment to create.
     * @returns Created comment.
     */
    (comment: Comment): Promise<Comment>;
}
export declare function getComment(httpClient: HttpClient): GetCommentSignature;
interface GetCommentSignature {
    /**
     * Retrieves a comment.
     * @param - ID of the comment to retrieve.
     * @returns Retrieved comment.
     */
    (commentId: string): Promise<Comment>;
}
export declare function updateComment(httpClient: HttpClient): UpdateCommentSignature;
interface UpdateCommentSignature {
    /**
     * Updates a comment.
     *
     * Each time the comment is updated, `revision` increments by 1. The current `revision` must be
     * passed when updating the comment. This ensures you're working with the latest comment and
     * prevents unintended overwrites.
     * @param - Comment ID.
     * @returns Updated comment.
     */
    (_id: string, comment: UpdateComment): Promise<Comment>;
}
export declare function deleteComment(httpClient: HttpClient): DeleteCommentSignature;
interface DeleteCommentSignature {
    /**
     * Deletes a comment.
     *
     * This method deletes the `content` of the comment and sets its `status` to `DELETED`.
     * @param - ID of the comment to delete.
     */
    (commentId: string): Promise<void>;
}
export declare function moderateDraftContent(httpClient: HttpClient): ModerateDraftContentSignature;
interface ModerateDraftContentSignature {
    /**
     * Moderates the draft content of a comment.
     *
     * - `APPROVE`: Moves `draftContent` to `content` and updates the comment `status` to `PUBLISHED`.
     * - `REJECT`: Clears `draftContent` if comment `status` is `PUBLISHED` or, if comment `status` is `PENDING` it will keep `draftContent` the same and change `status` to `HIDDEN`.
     * @param - ID of the comment to moderate.
     * @param - Revision number, which increments by `1` each time the comment is updated.
     *
     * To prevent conflicting changes, the current `revision` must be passed when updating the comment.
     */
    (commentId: string, revision: string, options?: ModerateDraftContentOptions | undefined): Promise<ModerateDraftContentResponse>;
}
export declare function queryComments(httpClient: HttpClient): QueryCommentsSignature;
interface QueryCommentsSignature {
    /**
     * Creates a query to retrieve a list of comments.
     *
     * The `queryComments()` function builds a query to retrieve a list of comments and returns a [`CommentsQueryBuilder`](#commentsquerybuilder) object.
     *
     * The returned object contains the query definition, which is typically used to run the query using the [`find()`](#commentsquerybuilder/find) function.
     *
     * You can refine the query by chaining `CommentsQueryBuilder` functions onto the query. `CommentsQueryBuilder` functions enable you to sort, filter, and control the results that `queryComments()` returns.
     *
     * `queryComments()` runs with the following `CommentsQueryBuilder` default that you can override:
     * + `ascending("_id")`
     *
     * The functions that are chained to `queryComments()` are applied in the order they are called. For example, if you apply `ascending("voteSummary.netVoteCount")` and then `ascending("replyCount")`, the results are sorted first by the `"voteSummary.netVoteCount"`, and then, if there are multiple results with the same `"voteSummary.netVoteCount"`, the items are sorted by `"replyCount"`.
     *
     * The following `CommentsQueryBuilder` functions are supported for the `queryComments()` function. For a full description of the comment object, see the object returned for the [`items`](#commentsqueryresult/items) property in [`CommentsQueryResult`](#commentsqueryresult).
     * @param - App ID to query comments for.
     */
    (appId: string): CommentsQueryBuilder;
}
export declare function markComment(httpClient: HttpClient): MarkCommentSignature;
interface MarkCommentSignature {
    /**
     * Sets `marked` to `TRUE` to mark a comment.
     *
     * Call Query Comments to filter for marked comments to then apply customization to.
     * See Sample Flows for an example.
     * @param - ID of the comment to mark.
     */
    (commentId: string): Promise<MarkCommentResponse>;
}
export declare function unmarkComment(httpClient: HttpClient): UnmarkCommentSignature;
interface UnmarkCommentSignature {
    /**
     * Sets `marked` to `FALSE` to unmark a comment.
     * @param - ID of the comment to unmark.
     */
    (commentId: string): Promise<UnmarkCommentResponse>;
}
export declare function hideComment(httpClient: HttpClient): HideCommentSignature;
interface HideCommentSignature {
    /**
     * Hides a comment in a widget. The comment status becomes `HIDDEN`.
     * @param - ID of the comment to hide.
     */
    (commentId: string): Promise<HideCommentResponse>;
}
export declare function publishComment(httpClient: HttpClient): PublishCommentSignature;
interface PublishCommentSignature {
    /**
     * Publishes a comment with the `HIDDEN` status. The comment status becomes `PUBLISHED`.
     *
     * To publish a new comment, call Create Comment.
     * @param - ID of the comment to publish.
     */
    (commentId: string): Promise<PublishCommentResponse>;
}
export declare function countComments(httpClient: HttpClient): CountCommentsSignature;
interface CountCommentsSignature {
    /**
     * Counts comments, given the specified filtering. Comments with the `HIDDEN` status are not included in the response.
     * @param - App ID to count the comments of.
     */
    (appId: string, options?: CountCommentsOptions | undefined): Promise<CountCommentsResponse>;
}
export declare function listCommentsByResource(httpClient: HttpClient): ListCommentsByResourceSignature;
interface ListCommentsByResourceSignature {
    /**
     * Lists published comments and replies from a specified resource, such as a blog post.
     * @param - ID of the app from which the comments are listed.
     */
    (appId: string, options?: ListCommentsByResourceOptions | undefined): Promise<ListCommentsByResourceResponse>;
}
export declare function getCommentThread(httpClient: HttpClient): GetCommentThreadSignature;
interface GetCommentThreadSignature {
    /**
     * Returns a thread of a comment or a reply.
     *
     * If you request a comment thread, the method returns a single comment with cursors. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
     *
     * If you request a reply thread, the method returns a reply with its parent comment. With cursors (`pagingMetadata.cursors.next` or `pagingMetadata.cursors.prev`) you can load replies by calling the List Comments by Resource method.
     * @param - Comment ID.
     */
    (commentId: string, options?: GetCommentThreadOptions | undefined): Promise<GetCommentThreadResponse>;
}
export declare function bulkPublishComment(httpClient: HttpClient): BulkPublishCommentSignature;
interface BulkPublishCommentSignature {
    /**
     * Publishes multiple comments with the `HIDDEN` status. The comment status becomes `PUBLISHED`.
     * @param - ID of the app where to publish the comment.
     */
    (appId: string, options: BulkPublishCommentOptions): Promise<BulkPublishCommentResponse>;
}
export declare function bulkHideComment(httpClient: HttpClient): BulkHideCommentSignature;
interface BulkHideCommentSignature {
    /**
     * Hides multiple comments. The comment status becomes `HIDDEN`.
     * @param - ID of the app where to hide the comments.
     */
    (appId: string, options: BulkHideCommentOptions): Promise<BulkHideCommentResponse>;
}
export declare function bulkDeleteComment(httpClient: HttpClient): BulkDeleteCommentSignature;
interface BulkDeleteCommentSignature {
    /**
     * Deletes multiple comments.
     * @param - ID of the app where to delete the comments.
     */
    (appId: string, options: BulkDeleteCommentOptions): Promise<BulkDeleteCommentResponse>;
}
export declare function bulkModerateDraftContent(httpClient: HttpClient): BulkModerateDraftContentSignature;
interface BulkModerateDraftContentSignature {
    /**
     * Moderates the draft content of multiple comments.
     * @param - ID of the app where to moderate the comments.
     */
    (appId: string, options: BulkModerateDraftContentOptions): Promise<BulkModerateDraftContentResponse>;
}
export declare function bulkMoveCommentByFilter(httpClient: HttpClient): BulkMoveCommentByFilterSignature;
interface BulkMoveCommentByFilterSignature {
    /**
     * Moves multiple comments to another resource.
     * @param - ID of the app from which to move the comments.
     */
    (appId: string, options?: BulkMoveCommentByFilterOptions | undefined): Promise<BulkMoveCommentByFilterResponse>;
}
export declare const onCommentContentChanged: EventDefinition<CommentContentChangedEnvelope, "wix.comments.v2.comment_comment_content_changed">;
export declare const onCommentHidden: EventDefinition<CommentHiddenEnvelope, "wix.comments.v2.comment_comment_hidden">;
export declare const onCommentMarked: EventDefinition<CommentMarkedEnvelope, "wix.comments.v2.comment_comment_marked">;
export declare const onCommentMoved: EventDefinition<CommentMovedEnvelope, "wix.comments.v2.comment_comment_moved">;
export declare const onCommentPublished: EventDefinition<CommentPublishedEnvelope, "wix.comments.v2.comment_comment_published">;
export declare const onCommentUnmarked: EventDefinition<CommentUnmarkedEnvelope, "wix.comments.v2.comment_comment_unmarked">;
export declare const onCommentCreated: EventDefinition<CommentCreatedEnvelope, "wix.comments.v2.comment_created">;
export declare const onCommentResourceCommentCountChanged: EventDefinition<CommentResourceCommentCountChangedEnvelope, "wix.comments.v2.comment_resource_comment_count_changed">;
export declare const onCommentUpdated: EventDefinition<CommentUpdatedEnvelope, "wix.comments.v2.comment_updated">;
export { Action, ActionEvent, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, Attachment, AttachmentMediaOneOf, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, BaseEventMetadata, BlockquoteData, BookingData, Border, BorderColors, BulkDeleteCommentOptions, BulkDeleteCommentRequest, BulkDeleteCommentResponse, BulkHideCommentOptions, BulkHideCommentRequest, BulkHideCommentResponse, BulkModerateDraftContentOptions, BulkModerateDraftContentRequest, BulkModerateDraftContentResponse, BulkMoveCommentByFilterOptions, BulkMoveCommentByFilterRequest, BulkMoveCommentByFilterResponse, BulkPublishCommentOptions, BulkPublishCommentRequest, BulkPublishCommentResponse, BulletedListData, ButtonData, CaptionData, CellStyle, CodeBlockData, CollapsibleListData, ColorData, Colors, Comment, CommentAuthor, CommentAuthorIdentityOneOf, CommentContent, CommentContentChanged, CommentContentChangedEnvelope, CommentCreatedEnvelope, CommentDeleted, CommentHidden, CommentHiddenEnvelope, CommentMarked, CommentMarkedEnvelope, CommentModerated, CommentMoved, CommentMovedEnvelope, CommentPublished, CommentPublishedEnvelope, CommentReactionSummary, CommentResourceCommentCountChangedEnvelope, CommentSort, CommentUnmarked, CommentUnmarkedEnvelope, CommentUpdatedEnvelope, CommentsQueryBuilder, CommentsQueryResult, ContactDetails, ContentAuthor, ContentAuthorAuthorOneOf, CountCommentsOptions, CountCommentsRequest, CountCommentsResponse, CreateCommentRequest, CreateCommentResponse, Crop, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, Decoration, DecorationDataOneOf, DecorationType, DeleteByFilterOperation, DeleteByIdsOperation, DeleteCommentRequest, DeleteCommentResponse, Design, Destination, Dimensions, Direction, DividerData, DocumentStyle, DomainEvent, DomainEventBodyOneOf, EmbedData, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventData, EventMetadata, FileData, FileSource, FileSourceDataOneOf, FontSizeData, FontType, GIF, GIFData, GIFType, GalleryData, GalleryOptions, GetCommentRequest, GetCommentResponse, GetCommentThreadOptions, GetCommentThreadRequest, GetCommentThreadResponse, Gradient, HTMLData, HTMLDataDataOneOf, HeadingData, Height, HideCommentRequest, HideCommentResponse, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, InitialExpandedItems, InternalDocument, InternalDocumentUpdateByFilterOperation, InternalDocumentUpdateOperation, InternalUpdateExistingOperation, Item, ItemDataOneOf, ItemStyle, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, LinkPreviewDataStyles, ListCommentsByResourceCursorPaging, ListCommentsByResourceOptions, ListCommentsByResourceRequest, ListCommentsByResourceResponse, ListValue, MapData, MapSettings, MapType, MarkCommentRequest, MarkCommentResponse, Media, Mention, MentionData, MentionIdentityOneOf, MessageEnvelope, Metadata, ModerateDraftContentOptions, ModerateDraftContentRequest, ModerateDraftContentResponse, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Oembed, Option, OptionDesign, OptionLayout, Order, OrderedListData, Orientation, PDFSettings, ParagraphData, ParentComment, Permissions, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, Position, PublishCommentRequest, PublishCommentResponse, QueryCommentsRequest, QueryCommentsResponse, Rel, RepliesListResponse, ReplySort, ReplySortOrder, ResourceCommentCountChanged, RestoreInfo, RichContent, Settings, SortOrder, Sorting, Source, Spoiler, SpoilerData, Status, Styles, StylesBorder, TableCellData, TableData, Target, TextAlignment, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, Type, UnmarkCommentRequest, UnmarkCommentResponse, UpdateComment, UpdateCommentRequest, UpdateCommentResponse, UpdateInternalDocumentsEvent, UpdateInternalDocumentsEventOperationOneOf, VersionedDeleteByIdsOperation, VersionedDocumentId, VersionedDocumentUpdateOperation, VersioningMode, VerticalAlignment, Video, VideoData, VideoResolution, ViewMode, ViewRole, VoteRole, VoteSummary, WebhookIdentityType, Width, WidthType, } from './comments-v2-comment-comments.universal.js';
